==> vala-0.0.9.tar.bz2: vala-0.0.9/vala/parser.h <==
/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     OPEN_BRACE = 258,
     CLOSE_BRACE = 259,
     OPEN_PARENS = 260,
     OPEN_CAST_PARENS = 261,
     CLOSE_PARENS = 262,
     BRACKET_PAIR = 263,
     OPEN_BRACKET = 264,
     CLOSE_BRACKET = 265,
     ELLIPSIS = 266,
     DOT = 267,
     COLON = 268,
     COMMA = 269,
     SEMICOLON = 270,
     HASH = 271,
     INTERR = 272,
     ASSIGN_BITWISE_OR = 273,
     ASSIGN_BITWISE_AND = 274,
     ASSIGN_BITWISE_XOR = 275,
     ASSIGN_ADD = 276,
     ASSIGN_SUB = 277,
     ASSIGN_MUL = 278,
     ASSIGN_DIV = 279,
     ASSIGN_PERCENT = 280,
     ASSIGN_SHIFT_LEFT = 281,
     ASSIGN_SHIFT_RIGHT = 282,
     OP_INC = 283,
     OP_DEC = 284,
     OP_EQ = 285,
     OP_NE = 286,
     OP_SHIFT_LEFT = 287,
     OP_SHIFT_RIGHT = 288,
     OP_LE = 289,
     OP_GE = 290,
     LAMBDA = 291,
     GENERIC_LT = 292,
     OP_LT = 293,
     OP_GT = 294,
     OP_NEG = 295,
     CARRET = 296,
     BITWISE_OR = 297,
     BITWISE_AND = 298,
     OP_OR = 299,
     OP_AND = 300,
     TILDE = 301,
     ASSIGN = 302,
     PLUS = 303,
     MINUS = 304,
     STAR = 305,
     DIV = 306,
     PERCENT = 307,
     ABSTRACT = 308,
     BASE = 309,
     BREAK = 310,
     CALLBACK = 311,
     CASE = 312,
     CATCH = 313,
     CLASS = 314,
     CONST = 315,
     CONSTRUCT = 316,
     CONTINUE = 317,
     DEFAULT = 318,
     DO = 319,
     ELSE = 320,
     ENUM = 321,
     VALA_FALSE = 322,
     FINALLY = 323,
     FLAGS = 324,
     FOR = 325,
     FOREACH = 326,
     GET = 327,
     IF = 328,
     IN = 329,
     INTERFACE = 330,
     IS = 331,
     LOCK = 332,
     NAMESPACE = 333,
     NEW = 334,
     VALA_NULL = 335,
     OUT = 336,
     OVERRIDE = 337,
     PRIVATE = 338,
     PROTECTED = 339,
     PUBLIC = 340,
     REF = 341,
     RETURN = 342,
     SET = 343,
     SIGNAL = 344,
     STATIC = 345,
     STRUCT = 346,
     SWITCH = 347,
     THIS = 348,
     THROW = 349,
     THROWS = 350,
     VALA_TRUE = 351,
     TRY = 352,
     TYPEOF = 353,
     USING = 354,
     VAR = 355,
     VIRTUAL = 356,
     WEAK = 357,
     WHILE = 358,
     IDENTIFIER = 359,
     INTEGER_LITERAL = 360,
     REAL_LITERAL = 361,
     CHARACTER_LITERAL = 362,
     STRING_LITERAL = 363
   };
#endif
/* Tokens.  */
#define OPEN_BRACE 258
#define CLOSE_BRACE 259
#define OPEN_PARENS 260
#define OPEN_CAST_PARENS 261
#define CLOSE_PARENS 262
#define BRACKET_PAIR 263
#define OPEN_BRACKET 264
#define CLOSE_BRACKET 265
#define ELLIPSIS 266
#define DOT 267
#define COLON 268
#define COMMA 269
#define SEMICOLON 270
#define HASH 271
#define INTERR 272
#define ASSIGN_BITWISE_OR 273
#define ASSIGN_BITWISE_AND 274
#define ASSIGN_BITWISE_XOR 275
#define ASSIGN_ADD 276
#define ASSIGN_SUB 277
#define ASSIGN_MUL 278
#define ASSIGN_DIV 279
#define ASSIGN_PERCENT 280
#define ASSIGN_SHIFT_LEFT 281
#define ASSIGN_SHIFT_RIGHT 282
#define OP_INC 283
#define OP_DEC 284
#define OP_EQ 285
#define OP_NE 286
#define OP_SHIFT_LEFT 287
#define OP_SHIFT_RIGHT 288
#define OP_LE 289
#define OP_GE 290
#define LAMBDA 291
#define GENERIC_LT 292
#define OP_LT 293
#define OP_GT 294
#define OP_NEG 295
#define CARRET 296
#define BITWISE_OR 297
#define BITWISE_AND 298
#define OP_OR 299
#define OP_AND 300
#define TILDE 301
#define ASSIGN 302
#define PLUS 303
#define MINUS 304
#define STAR 305
#define DIV 306
#define PERCENT 307
#define ABSTRACT 308
#define BASE 309
#define BREAK 310
#define CALLBACK 311
#define CASE 312
#define CATCH 313
#define CLASS 314
#define CONST 315
#define CONSTRUCT 316
#define CONTINUE 317
#define DEFAULT 318
#define DO 319
#define ELSE 320
#define ENUM 321
#define VALA_FALSE 322
#define FINALLY 323
#define FLAGS 324
#define FOR 325
#define FOREACH 326
#define GET 327
#define IF 328
#define IN 329
#define INTERFACE 330
#define IS 331
#define LOCK 332
#define NAMESPACE 333
#define NEW 334
#define VALA_NULL 335
#define OUT 336
#define OVERRIDE 337
#define PRIVATE 338
#define PROTECTED 339
#define PUBLIC 340
#define REF 341
#define RETURN 342
#define SET 343
#define SIGNAL 344
#define STATIC 345
#define STRUCT 346
#define SWITCH 347
#define THIS 348
#define THROW 349
#define THROWS 350
#define VALA_TRUE 351
#define TRY 352
#define TYPEOF 353
#define USING 354
#define VAR 355
#define VIRTUAL 356
#define WEAK 357
#define WHILE 358
#define IDENTIFIER 359
#define INTEGER_LITERAL 360
#define REAL_LITERAL 361
#define CHARACTER_LITERAL 362
#define STRING_LITERAL 363




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
#line 63 "parser.y"
{
	int num;
	char *str;
	GList *list;
	ValaLiteral *literal;
	ValaTypeReference *type_reference;
	ValaExpression *expression;
	ValaStatement *statement;
	ValaNamespace *namespace;
	ValaClass *class;
	ValaStruct *struct_;
	ValaInterface *interface;
	ValaEnum *enum_;
	ValaEnumValue *enum_value;
	ValaFlags *flags;
	ValaFlagsValue *flags_value;
	ValaCallback *callback;
	ValaConstant *constant;
	ValaField *field;
	ValaMethod *method;
	ValaFormalParameter *formal_parameter;
	ValaProperty *property;
	ValaPropertyAccessor *property_accessor;
	ValaSignal *signal;
	ValaConstructor *constructor;
	ValaDestructor *destructor;
	ValaLocalVariableDeclaration *local_variable_declaration;
	ValaVariableDeclarator *variable_declarator;
	ValaTypeParameter *type_parameter;
	ValaAttribute *attribute;
	ValaNamedArgument *named_argument;
	ValaSwitchSection *switch_section;
	ValaSwitchLabel *switch_label;
	ValaCatchClause *catch_clause;
}
/* Line 1489 of yacc.c.  */
#line 301 "parser.h"
	YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif



#if ! defined YYLTYPE && ! defined YYLTYPE_IS_DECLARED
typedef struct YYLTYPE
{
  int first_line;
  int first_column;
  int last_line;
  int last_column;
} YYLTYPE;
# define yyltype YYLTYPE /* obsolescent; will be withdrawn */
# define YYLTYPE_IS_DECLARED 1
# define YYLTYPE_IS_TRIVIAL 1
#endif

==> vala-0.1.2.tar.bz2: vala-0.1.2/vala/parser.h <==
/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     OPEN_BRACE = 258,
     CLOSE_BRACE = 259,
     OPEN_PARENS = 260,
     OPEN_CAST_PARENS = 261,
     CLOSE_PARENS = 262,
     BRACKET_PAIR = 263,
     OPEN_BRACKET = 264,
     CLOSE_BRACKET = 265,
     ELLIPSIS = 266,
     DOT = 267,
     COLON = 268,
     COMMA = 269,
     SEMICOLON = 270,
     HASH = 271,
     INTERR = 272,
     ASSIGN_BITWISE_OR = 273,
     ASSIGN_BITWISE_AND = 274,
     ASSIGN_BITWISE_XOR = 275,
     ASSIGN_ADD = 276,
     ASSIGN_SUB = 277,
     ASSIGN_MUL = 278,
     ASSIGN_DIV = 279,
     ASSIGN_PERCENT = 280,
     ASSIGN_SHIFT_LEFT = 281,
     ASSIGN_SHIFT_RIGHT = 282,
     OP_INC = 283,
     OP_DEC = 284,
     OP_EQ = 285,
     OP_NE = 286,
     OP_SHIFT_LEFT = 287,
     OP_SHIFT_RIGHT = 288,
     OP_LE = 289,
     OP_GE = 290,
     LAMBDA = 291,
     GENERIC_LT = 292,
     OP_LT = 293,
     OP_GT = 294,
     OP_NEG = 295,
     CARRET = 296,
     BITWISE_OR = 297,
     BITWISE_AND = 298,
     OP_OR = 299,
     OP_AND = 300,
     TILDE = 301,
     ASSIGN = 302,
     PLUS = 303,
     MINUS = 304,
     STAR = 305,
     DIV = 306,
     PERCENT = 307,
     ABSTRACT = 308,
     BASE = 309,
     BREAK = 310,
     CASE = 311,
     CATCH = 312,
     CLASS = 313,
     CONST = 314,
     CONSTRUCT = 315,
     CONTINUE = 316,
     DEFAULT = 317,
     DELEGATE = 318,
     DO = 319,
     ELSE = 320,
     ENUM = 321,
     VALA_FALSE = 322,
     FINALLY = 323,
     FOR = 324,
     FOREACH = 325,
     GET = 326,
     IF = 327,
     IN = 328,
     INTERFACE = 329,
     IS = 330,
     LOCK = 331,
     NAMESPACE = 332,
     NEW = 333,
     VALA_NULL = 334,
     OUT = 335,
     OVERRIDE = 336,
     PRIVATE = 337,
     PROTECTED = 338,
     PUBLIC = 339,
     REF = 340,
     RETURN = 341,
     SET = 342,
     SIGNAL = 343,
     SIZEOF = 344,
     STATIC = 345,
     STRUCT = 346,
     SWITCH = 347,
     THIS = 348,
     THROW = 349,
     THROWS = 350,
     VALA_TRUE = 351,
     TRY = 352,
     TYPEOF = 353,
     USING = 354,
     VAR = 355,
     VIRTUAL = 356,
     WEAK = 357,
     WHILE = 358,
     IDENTIFIER = 359,
     INTEGER_LITERAL = 360,
     REAL_LITERAL = 361,
     CHARACTER_LITERAL = 362,
     STRING_LITERAL = 363
   };
#endif
/* Tokens.  */
#define OPEN_BRACE 258
#define CLOSE_BRACE 259
#define OPEN_PARENS 260
#define OPEN_CAST_PARENS 261
#define CLOSE_PARENS 262
#define BRACKET_PAIR 263
#define OPEN_BRACKET 264
#define CLOSE_BRACKET 265
#define ELLIPSIS 266
#define DOT 267
#define COLON 268
#define COMMA 269
#define SEMICOLON 270
#define HASH 271
#define INTERR 272
#define ASSIGN_BITWISE_OR 273
#define ASSIGN_BITWISE_AND 274
#define ASSIGN_BITWISE_XOR 275
#define ASSIGN_ADD 276
#define ASSIGN_SUB 277
#define ASSIGN_MUL 278
#define ASSIGN_DIV 279
#define ASSIGN_PERCENT 280
#define ASSIGN_SHIFT_LEFT 281
#define ASSIGN_SHIFT_RIGHT 282
#define OP_INC 283
#define OP_DEC 284
#define OP_EQ 285
#define OP_NE 286
#define OP_SHIFT_LEFT 287
#define OP_SHIFT_RIGHT 288
#define OP_LE 289
#define OP_GE 290
#define LAMBDA 291
#define GENERIC_LT 292
#define OP_LT 293
#define OP_GT 294
#define OP_NEG 295
#define CARRET 296
#define BITWISE_OR 297
#define BITWISE_AND 298
#define OP_OR 299
#define OP_AND 300
#define TILDE 301
#define ASSIGN 302
#define PLUS 303
#define MINUS 304
#define STAR 305
#define DIV 306
#define PERCENT 307
#define ABSTRACT 308
#define BASE 309
#define BREAK 310
#define CASE 311
#define CATCH 312
#define CLASS 313
#define CONST 314
#define CONSTRUCT 315
#define CONTINUE 316
#define DEFAULT 317
#define DELEGATE 318
#define DO 319
#define ELSE 320
#define ENUM 321
#define VALA_FALSE 322
#define FINALLY 323
#define FOR 324
#define FOREACH 325
#define GET 326
#define IF 327
#define IN 328
#define INTERFACE 329
#define IS 330
#define LOCK 331
#define NAMESPACE 332
#define NEW 333
#define VALA_NULL 334
#define OUT 335
#define OVERRIDE 336
#define PRIVATE 337
#define PROTECTED 338
#define PUBLIC 339
#define REF 340
#define RETURN 341
#define SET 342
#define SIGNAL 343
#define SIZEOF 344
#define STATIC 345
#define STRUCT 346
#define SWITCH 347
#define THIS 348
#define THROW 349
#define THROWS 350
#define VALA_TRUE 351
#define TRY 352
#define TYPEOF 353
#define USING 354
#define VAR 355
#define VIRTUAL 356
#define WEAK 357
#define WHILE 358
#define IDENTIFIER 359
#define INTEGER_LITERAL 360
#define REAL_LITERAL 361
#define CHARACTER_LITERAL 362
#define STRING_LITERAL 363




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
#line 66 "parser.y"
{
	int num;
	char *str;
	GList *list;
	ValaLiteral *literal;
	ValaTypeReference *type_reference;
	ValaExpression *expression;
	ValaStatement *statement;
	ValaBlock *block;
	ValaStruct *struct_;
	ValaInterface *interface;
	ValaEnumValue *enum_value;
	ValaConstant *constant;
	ValaField *field;
	ValaMethod *method;
	ValaFormalParameter *formal_parameter;
	ValaProperty *property;
	ValaPropertyAccessor *property_accessor;
	ValaSignal *signal;
	ValaConstructor *constructor;
	ValaDestructor *destructor;
	ValaLocalVariableDeclaration *local_variable_declaration;
	ValaVariableDeclarator *variable_declarator;
	ValaTypeParameter *type_parameter;
	ValaAttribute *attribute;
	ValaNamedArgument *named_argument;
	ValaSwitchSection *switch_section;
	ValaSwitchLabel *switch_label;
	ValaCatchClause *catch_clause;
}
/* Line 1489 of yacc.c.  */
#line 296 "parser.h"
	YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif



#if ! defined YYLTYPE && ! defined YYLTYPE_IS_DECLARED
typedef struct YYLTYPE
{
  int first_line;
  int first_column;
  int last_line;
  int last_column;
} YYLTYPE;
# define yyltype YYLTYPE /* obsolescent; will be withdrawn */
# define YYLTYPE_IS_DECLARED 1
# define YYLTYPE_IS_TRIVIAL 1
#endif
